==> patch-2.3.5.0.zip: app/views/settings/ssl.php <==
<?php

use \Core\View;
use \Helpers\Url;
 /*
 *
 * Copyright 2015
 * ParaBlu Systems Private Limited
 * All Rights Reserved
 *
 * NOTICE:  All information contained herein is, and remains
 * the property of ParaBlu Systems Private Limited and its suppliers, if any.
 * The intellectual and technical concepts contained herein are proprietary
 * to ParaBlu Systems Private Limited and its suppliers and may be covered by
 * Indian, US and Foreign Patents, patents in process, and are protected by
 * trade secret or copyright law.
 * Dissemination of this information or reproduction of this material
 * is strictly forbidden unless prior written permission is obtained
 * from ParaBlu Systems Private Limited.
 *
 * index.php
 *
 * @author Prashanth Kumar B - prashanth.kumar@parablu.com
 * @version 2.0
 * @date 7/10/15
 * @time 11:55 AM
 * 
 */
?>
<div class="container">
    <div class="row">
        <div class="col-lg-6">
            <ol class="breadcrumb">
                <li><h3><a href="<?=Url::basePath('settings')?>"><?=$data['title']?></a></h3></li>
                <li><?=$data['crumb1']?></li>
            </ol>
        </div>
        <div class="col-lg-6 hide">
            <?php View::renderTemplate('partials/createButton', $data)?>
        </div>
    </div>
</div>
<div class="main" ng-controller="SettingController">
    <div class="row profile">
        <div class="col-lg-1 col-md-1 col-sm-1">
            <?php View::renderTemplate('partials/sideBar', $data); ?>
        </div>
        <div class="col-lg-11 col-md-11 col-sm-11">
            <span class="csrf_token hide"><?=$data['csrf_token']?></span>
            <span class="currentPage hide"><?='dashboard'?></span>
            <div class="row">
                <div class="panel">
                    <div class="panel-heading">
                        <h4 style="padding: 0px 0px 0px 15px;">SSL Configuration</h4>
                    </div>
                    <div class="panel-body">
                        <form class="SSLConfiguration" data-parsley-validate enctype="multipart/form-data">
                            <div class="form-group col-lg-12">
                                <label for="mainCRTFile">Main Crt File</label>
                                <input type="file" class="form-control" name="mainCRTFile" id="mainCRTFile" required autocomplete="off">
                                <span class="help-line text-muted">Note:- files with an extension of .crt can only be uploaded.</span>
                            </div>
                            <div class="form-group col-lg-12">
                                <label for="chainCRTFile">Chain CRT File</label>
                                <input type="file" class="form-control" name="chainCRTFile" id="chainCRTFile" required autocomplete="off">
                                <span class="help-line text-muted">Note:- files with an extension of .crt can only be uploaded.</span>
                            </div>
                            <div class="form-group col-lg-12">
                                <label for="keyFile">Key File</label>
                                <input type="file" class="form-control" name="keyFile" id="keyFile" required autocomplete="off">
                                <span class="help-line text-muted">Note:- files with an extension of .key can only be uploaded.</span>
                                <br/>
                                <button type="submit" class="btn btn-success pull-right">Save Settings</button>
                            </div>
                        </form>
                    </div>
                </div>
            </div>
        </div>
    </div>
    <?php View::renderTemplate('partials/search', $data); ?>
</div><!-- /.container -->
<?php View::renderTemplate('partials/scripts')?>
<script src="<?=Url::templatePath()?>js/angular/controllers/SettingController.js?<?=VERSIONS_NUMBER?>" type="text/javascript"></script>

==> patch-2.5.3.15.zip: app/views/settings/ssl.php <==
<?php

use \Core\View;
use \Helpers\Url;
 /*
 *
 * Copyright 2015
 * ParaBlu Systems Private Limited
 * All Rights Reserved
 *
 * NOTICE:  All information contained herein is, and remains
 * the property of ParaBlu Systems Private Limited and its suppliers, if any.
 * The intellectual and technical concepts contained herein are proprietary
 * to ParaBlu Systems Private Limited and its suppliers and may be covered by
 * Indian, US and Foreign Patents, patents in process, and are protected by
 * trade secret or copyright law.
 * Dissemination of this information or reproduction of this material
 * is strictly forbidden unless prior written permission is obtained
 * from ParaBlu Systems Private Limited.
 *
 * index.php
 *
 * @author Prashanth Kumar B - prashanth.kumar@parablu.com
 * @version 2.0
 * @date 7/10/15
 * @time 11:55 AM
 * 
 */
?>
<div class="container">
    <div class="row">
        <div class="col-lg-6">
            <ol class="breadcrumb">
                <li><h3><a href="<?=Url::basePath('settings')?>"><?=$data['title']?></a></h3></li>
                <li><?=$data['crumb1']?></li>
            </ol>
        </div>
        <div class="col-lg-6 hide">
            <?php View::renderTemplate('partials/createButton', $data)?>
        </div>
    </div>
</div>
<div class="main" ng-controller="SettingController">
    <div class="row profile">
        <div class="col-lg-1 col-md-1 col-sm-1">
            <?php if(!isMobile()){ View::renderTemplate('partials/sideBar', $data); }?>
        </div>
        <div class="col-lg-11 col-md-11 col-sm-11">
            <span class="csrf_token hide"><?=$data['csrf_token']?></span>
            <span class="currentPage hide"><?='dashboard'?></span>
            <div class="row">
                <div class="panel">
                    <div class="panel-heading">
                        <h4 style="padding: 0px 0px 0px 15px;">SSL Configuration</h4>
                    </div>
                    <div class="panel-body">
                        <form class="SSLConfiguration" data-parsley-validate enctype="multipart/form-data">
                            <div class="form-group col-lg-12">
                                <label for="mainCRTFile">Main Crt File</label>
                                <input type="file" class="form-control" name="mainCRTFile" id="mainCRTFile" required autocomplete="off">
                                <span class="help-line text-muted">Note:- files with an extension of .crt can only be uploaded.</span>
                            </div>
                            <div class="form-group col-lg-12">
                                <label for="chainCRTFile">Chain CRT File</label>
                                <input type="file" class="form-control" name="chainCRTFile" id="chainCRTFile" required autocomplete="off">
                                <span class="help-line text-muted">Note:- files with an extension of .crt can only be uploaded.</span>
                            </div>
                            <div class="form-group col-lg-12">
                                <label for="keyFile">Key File</label>
                                <input type="file" class="form-control" name="keyFile" id="keyFile" required autocomplete="off">
                                <span class="help-line text-muted">Note:- files with an extension of .key can only be uploaded.</span>
                                <br/>
                                <button type="submit" class="btn btn-success pull-right">Save Settings</button>
                            </div>
                        </form>
                    </div>
                </div>
            </div>
        </div>
    </div>
    <?php View::renderTemplate('partials/search', $data); ?>
</div><!-- /.container -->
<?php View::renderTemplate('partials/scripts')?>
<script src="<?=Url::templatePath()?>js/angular/controllers/SettingController.js?<?=VERSIONS_NUMBER?>" type="text/javascript"></script>
